==> qtjambi-script-5.15.15-sources.jar: io/qt/script/QScriptExtensionInterface.java <==
package io.qt.script;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QScriptExtensionInterface</p>
 */
public interface QScriptExtensionInterface extends QtObjectInterface, io.qt.core.QFactoryInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.script.QScriptExtensionInterface}</p>
     */
    public static abstract class Impl extends QtObject
        implements io.qt.script.QScriptExtensionInterface,
                io.qt.core.QFactoryInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @NativeAccess
        private static final class ConcreteWrapper extends QScriptExtensionInterface.Impl {
            
            @NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @QtUninvokable
            public void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine){
                initialize_native_cref_QString_QScriptEngine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
            }
            private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
            
            
            @Override
            @QtUninvokable
            public java.util.@NonNull List<java.lang.@NonNull String> keys(){
                return keys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QScriptExtensionInterface instance);
        
        @QtUninvokable
        public abstract void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine);
        
        private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
        
        @QtUninvokable
        public abstract java.util.@NonNull List<java.lang.@NonNull String> keys();
        
        private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    @QtUninvokable
    public void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine);
    
    @QtUninvokable
    public java.util.@NonNull List<java.lang.@NonNull String> keys();
    
}

==> qtjambi-script-5.15.16-sources.jar: io/qt/script/QScriptExtensionInterface.java <==
package io.qt.script;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QScriptExtensionInterface</code></p>
 */
public interface QScriptExtensionInterface extends QtObjectInterface, io.qt.core.QFactoryInterface
{
    /**
     * @hidden
     * <p>Implementor class for interface {@link io.qt.script.QScriptExtensionInterface}</p>
     */
    public static abstract class Impl extends QtObject
        implements io.qt.script.QScriptExtensionInterface,
                io.qt.core.QFactoryInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @NativeAccess
        private static final class ConcreteWrapper extends QScriptExtensionInterface.Impl {
            
            @NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @QtUninvokable
            public void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine){
                initialize_native_cref_QString_QScriptEngine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
            }
            private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
            
            
            @Override
            @QtUninvokable
            public java.util.@NonNull List<java.lang.@NonNull String> keys(){
                return keys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
            
        }
        
        
        /**
         * <p>See <code>QScriptExtensionInterface::<wbr>QScriptExtensionInterface()</code></p>
         */
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QScriptExtensionInterface instance);
        
        /**
         * <p>See <code>QScriptExtensionInterface::<wbr>initialize(QString,<wbr>QScriptEngine*)</code></p>
         */
        @QtUninvokable
        public abstract void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine);
        
        private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
        
        /**
         * <p>See <code>QFactoryInterface::<wbr>keys()const</code></p>
         */
        @QtUninvokable
        public abstract java.util.@NonNull List<java.lang.@NonNull String> keys();
        
        private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         * @hidden
         */
        @NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <code>QScriptExtensionInterface::<wbr>initialize(QString,<wbr>QScriptEngine*)</code></p>
     */
    @QtUninvokable
    public void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine);
    
    /**
     * <p>See <code>QFactoryInterface::<wbr>keys()const</code></p>
     */
    @QtUninvokable
    public java.util.@NonNull List<java.lang.@NonNull String> keys();
    
}
